English | [Portuguese](README_ptbr.md)

# Statistic

This is a library developed in Python that aims to provide the necessary functions to perform statistical calculations.

> Note: The library is still under development.

### Summary

  - [How to use](#how-to-use)
  - [Architecture](#architecture)
  - [Documentations](#documentations)

## How to use

Go to your terminal, navigate to your project folder and enter the following command:

```
pip install sttc
```

## Architecture

Below is the project folder architecture:

- `/Statistic`
  - `/documentation`
    - `english`
    - `português-brasil`
  - `/img`
  - `/others` (hidden for now)
  - `/statistic`
  
### `/Statistic`

It is the main project folder.

### `/documentation`

This folder contains the translated documentation (English and Brazilian Portuguese, for now).

### `/english`

Contains documentation for modules in English.

### `/português-brasil`

Contains the modules documentation in Brazilian Portuguese language.

### `/img`

In this folder are the images used in the project.

### `/others`

In this one, there are sketches and things related to that.

### `/statistic`

This is the folder where the modules are located. In short, it is the main package of the project.

It has a `__init__.py` file where the module functions are imported.

## Documentations

This project, so far, contains 2 modules with functions. To find out more details about each function, go to `/documentation`, choose the folder with the language of your choice and there will be the function documentation files.

> Note: Whenever there is a change in any of the functions the documentation will change.